/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.jmock;

import org.hamcrest.Matcher;
import org.jmock.Expectations;
import org.jmock.Mockery;

/**
 * Class for simple utilities for JMock.
 *
 * @author Jared Bunting
 */
public class JMockUtils {
  private JMockUtils() {
  }

  /**
   * Implements the comparable interface on a mock object.
   * @param context the mockery
   * @param mock the mock object
   * @param less 
   * @param equals
   * @param greater
   * @param <T>
   */
  public static <T extends Comparable> void mockComparable(Mockery context,
                                                           final T mock,
                                                           final Matcher<T> less,
                                                           final Matcher<T> equals,
                                                           final Matcher<T> greater) {
    context.checking(new Expectations() {{
      if(less != null) {
        allowing(mock).compareTo(with(less));
          will(returnValue(-1));
      }
      if(equals != null) {
        allowing(mock).compareTo(with(equals));
          will(returnValue(0));
      }
      if(greater != null) {
        allowing(mock).compareTo(with(greater));
          will(returnValue(1));
      }
    }});
  }

}
